# Generated by Django 3.0.6 on 2021-07-19 10:38

import django.contrib.postgres.indexes
from django.db import migrations, models
import djangorestfilemanager.models


class Migration(migrations.Migration):

    dependencies = [
        ('djangorestfilemanager', '0008_alter_file_field'),
    ]

    operations = [
        migrations.AlterField(
            model_name='file',
            name='file',
            field=models.FileField(null=True, upload_to=djangorestfilemanager.models.set_storage_file_dir, verbose_name='File'),
        ),
        migrations.AlterField(
            model_name='file',
            name='type',
            field=models.CharField(blank=True, db_index=True, default='file', max_length=10, null=True, verbose_name='Type'),
        ),
        migrations.AddIndex(
            model_name='file',
            index=django.contrib.postgres.indexes.BrinIndex(fields=['creation_date'], name='djangorestf_creatio_af499f_brin'),
        ),
    ]



# Generated by Django 3.0.4 on 2020-03-18 17:06

from django.db import migrations, models
import djangorestfilemanager.models


class Migration(migrations.Migration):

    dependencies = [
        ('djangorestfilemanager', '0003_auto_20200311_1022'),
    ]

    operations = [
        migrations.AlterField(
            model_name='file',
            name='file',
            field=models.FileField(null=True, storage=djangorestfilemanager.models.RestFileManagerStorage(location='s3_uploader'), upload_to=djangorestfilemanager.models.set_storage_file_dir, verbose_name='File'),
        ),
    ]



# Generated by Django 3.0.2 on 2020-04-29 10:20

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangorestfilemanager', '0005_auto_20200319_1235'),
    ]

    operations = [
        migrations.AddField(
            model_name='file',
            name='data',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, default=dict, null=True),
        ),
    ]



from rest_framework.permissions import IsAuthenticated


class FilePermissions(IsAuthenticated):

    def has_permission(self, request, view):
        return super().has_permission(request, view)

    def has_object_permission(self, request, view, obj):
        permissions_ok = obj.permission == '' or request.user.has_perm(obj.permission)
        is_owner = obj.username == request.user.username
        return request.user.is_superuser or is_owner or (obj.share and permissions_ok)



from django.db import migrations, models
import djangorestfilemanager.models


class Migration(migrations.Migration):

    dependencies = [
        ('djangorestfilemanager', '0007_alter_file_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='file',
            name='file',
            field=models.FileField(max_length=255, null=True, upload_to=djangorestfilemanager.models.set_storage_file_dir, verbose_name='File'),
        ),
    ]
